@@ -52,7 +52,7 @@ class WSDappDev   :public WSDdev{
     WSCindexData _ext_policy_list;
     WSCstring _ext_policy_name;
     WSCindexData* _current_policy_fn_list;
-
+    WSCbool   _under_exec_init;
 
     static WSDappDev*   _instance;
     static WSClistData* _init_handler;
@@ -122,7 +122,7 @@ class WSDappDev   :public WSDdev{
     void setExtGuiPolicyProc(char* policy_name,char* procname,void(*)(void*));
     void* getExtGuiPolicyProc(char* procname);
     WSCindexData* getExtGuiPolicyList();
-
+    WSCbool getUnderExecInitialize();
     WSMFclassDef(WSDappDev,WSDdev);
 };
 extern WSDLEX WSDappDev*  WSGIappDev();
