@@ -125,7 +125,8 @@ class WSCprojectEditor :public WSCbaseDialog{
     WSCvbtn*    _pe_bt1;
     WSCvbtn*    _pe_btn3;
     WSCoption*  _opt1;
-    WSCvradio*  _pe_radio1;
+//    WSCvradio*  _pe_radio1;
+    WSCoption*  _opt4;
     WSCvradio*  _pe_radio2;
 //    WSCvradio*  _pe_radio3;
 //    WSCvradio*  _polvrad_002;
@@ -139,7 +140,17 @@ class WSCprojectEditor :public WSCbaseDialog{
 
     WSClistData  _look_and_feel_name_list;
     WSClistData  _look_and_feel_value_list;
+    WSCindexData  _target_suffix_name_list;
+    WSCindexData  _target_env_name_list;
 
+    WSCvifield* _cpe_ifi001;
+    WSCvifield* _cpe_ifi002;
+    WSCvifield* _cpe_ifi003;
+    WSCvifield* _cpe_ifi004;
+    WSCvifield* _cpe_ifi005;
+    WSCstring _linkoptions_fname;
+    WSCstring _default_prj_fname;
+    long _target_no;
 //    WSCinputDialog* _pe_inputd;
 //WSCcolorSelect* _pe_colord;
 
@@ -160,8 +171,10 @@ class WSCprojectEditor :public WSCbaseDialog{
     static void _pe_fbt7_work(WSCbase*);
     static void _pe_fbt8_work(WSCbase*);
     static void _pe_fbt9_work(WSCbase*);
+    static void _cpe_fbt_work(WSCbase*);
 
     static void _editor_option_work(WSCbase*);
+    static void _target_option_work(WSCbase*);
 
     virtual void onResize(WSCrect* rect);
     virtual void onActivate();
@@ -170,6 +183,8 @@ class WSCprojectEditor :public WSCbaseDialog{
     void  _update_data(WSCindexData*,WSCindexData*);
     void  _cancel_data(WSCindexData*,WSCindexData*);
     static void  _compat_work(WSCbase*);
+    long  _reload_project();
+    void _loadLinkOptions(WSCstring*);
 
   public:
     WSCprojectEditor(WSCbase*,char*);
@@ -180,11 +195,13 @@ class WSCprojectEditor :public WSCbaseDialog{
     virtual void onGuiPolicyChange(long);
     virtual void onVisibleChange(WSCbool);
 
+    void  setDefaultProjectName(char* );
     long  open(char* );
     long  save(char* );
     long  open_global(char* );
     long  save_global(char* );
 
+    WSCstring getProjectDataFromFile(char* fname,char* index);
     char* getProjectData(char* index = NULL);
     char* getProjectData(char* index,WSCindexData*,WSCindexData*);
     void  updateData();
@@ -199,6 +216,7 @@ class WSCprojectEditor :public WSCbaseDialog{
     void  setEncodingMenu(char* menu,long default_value);
     long getLanguage();
     void setLanguage(long);
+    WSCbool getOldSwigMapping();
 
     WSCstring getGuiPolicy();
     void setGuiPolicy(char*);
@@ -207,6 +225,9 @@ class WSCprojectEditor :public WSCbaseDialog{
     void loadLinkOptions(char*);
     WSCstring getLinkOptions(long);
 
+    WSCstring getTargetSuffixName();
+    WSCstring getTargetEnvironment();
+
     WSMFguiClassDef(WSCprojectEditor,WSCbaseDialog);
     WSMFversionDef(WSCprojectEditor);
 };
