@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -57,7 +57,7 @@ class WSDxappDev               :public WSDappDev {
 virtual long handleEvents();
 virtual long dispatchEvent();
 virtual long processEvent();
-        long _dispatchEvent(WSCbool wait);
+        long _dispatchEvent(WSCbool wait,XEvent* e = NULL);
 virtual long initialize();
 Display*       display();
 Widget         appWidget();
