@@ -133,7 +133,7 @@
   WSGIappLocaleSet()->setLocaleString("C","U3:WSSTR Class library","Class library");
   WSGIappLocaleSet()->setLocaleString("C","V3:WSSTR  Generate class library"," Generate class library");
   WSGIappLocaleSet()->setLocaleString("C","W3:WSSTR Compiler","Compiler");
-  WSGIappLocaleSet()->setLocaleString("C","X3:WSSTR Runtime mode,Debug mode","Runtime mode,Debug mode");
+  WSGIappLocaleSet()->setLocaleString("C","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","Runtime mode,Debug mode,Runtime static mode,Debug static mode");
   WSGIappLocaleSet()->setLocaleString("C","Y3:WSSTR Include path","Include path");
   WSGIappLocaleSet()->setLocaleString("C","Z3:WSSTR Compiler flags","Compiler flags");
   WSGIappLocaleSet()->setLocaleString("C","a3:WSSTR Include path","Include path");
@@ -202,7 +202,7 @@
   WSGIappLocaleSet()->setLocaleString("C","k3:WSSTR Belong to this project","Belong to this project");
   WSGIappLocaleSet()->setLocaleString("C","l3:WSSTR Member","Member");
   WSGIappLocaleSet()->setLocaleString("C","l3:WSSTR ENCODING","ENCODING");
-  WSGIappLocaleSet()->setLocaleString("C","l3:WSSTR COMPAT","COMPATIBLE");
+  WSGIappLocaleSet()->setLocaleString("C","l3:WSSTR COMPAT","TARGET");
   WSGIappLocaleSet()->setLocaleString("C","l3:WSSTR Platform compatible","Platform compatible");
   WSGIappLocaleSet()->setLocaleString("C","l3:WSSTR Gui Policy","Gui Policy");
   WSGIappLocaleSet()->setLocaleString("C","l3:WSSTR Look & Feel","Look & Feel");
@@ -246,4 +246,7 @@
   WSGIappLocaleSet()->setLocaleString("C","P3:WSSTR Python(DBG)","Python(DBG)");
   WSGIappLocaleSet()->setLocaleString("C","P3:WSSTR Perl","Perl");
   WSGIappLocaleSet()->setLocaleString("C","P3:WSSTR Perl(DBG)","Perl(DBG)");
+  WSGIappLocaleSet()->setLocaleString("C","f3:WSSTR Static option","Static option");
+  WSGIappLocaleSet()->setLocaleString("C","l3:WSSTR Dynamically linked","Dynamically linked");
+  WSGIappLocaleSet()->setLocaleString("C","l3:WSSTR Statically linked","Statically linked");
 
