@@ -202,8 +202,8 @@
   WSGIappLocaleSet()->setLocaleString("SJIS","k3:WSSTR Belong to this project","vWFNg֓o^");
   WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Member","o");
   WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR ENCODING","R[ȟn");
-  WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR COMPAT","݊");
-  WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Platform compatible","vbgz[݊");
+  WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR COMPAT","TARGET");
+  WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Platform compatible","vbgtH[݊");
   WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Look & Feel","Look & Feel");
   WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Gradation","Gradation");
   WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Gui Policy","fth|V[");
@@ -232,10 +232,10 @@
   WSGIappLocaleSet()->setLocaleString("SJIS","R3:WSSTR The method name is already used.","w肳ꂽ\x83\\bĥ͊ɎgpĂ܂B");
   WSGIappLocaleSet()->setLocaleString("SJIS","S3:WSSTR Invalid method name.","sȃ\x83\\bĥłB");
   WSGIappLocaleSet()->setLocaleString("SJIS","V3:WSSTR Please select the method.","\x83\\bhIĂB");
-  WSGIappLocaleSet()->setLocaleString("SJIS","d3:WSSTR RemoteClassName:","z[gNX");
-  WSGIappLocaleSet()->setLocaleString("SJIS","d3:WSSTR BaseClassName:","hz[gNX");
+  WSGIappLocaleSet()->setLocaleString("SJIS","d3:WSSTR RemoteClassName:","z[gNX:");
+  WSGIappLocaleSet()->setLocaleString("SJIS","d3:WSSTR BaseClassName:","hz[gNX:");
   WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Language","");
-  WSGIappLocaleSet()->setLocaleString("SJIS","K3:WSSTR Edit...", "ݒ...");
+  WSGIappLocaleSet()->setLocaleString("SJIS","K3:WSSTR Edit...","ݒ...");
   WSGIappLocaleSet()->setLocaleString("SJIS","W3:WSSTR Name of the struct:","\x8d\\̖");
   WSGIappLocaleSet()->setLocaleString("SJIS","W3:WSSTR Name of the value:","l");
   WSGIappLocaleSet()->setLocaleString("SJIS","W3:WSSTR Value:","l");
@@ -246,7 +246,6 @@
   WSGIappLocaleSet()->setLocaleString("SJIS","P3:WSSTR Python(DBG)","Python(DBG)");
   WSGIappLocaleSet()->setLocaleString("SJIS","P3:WSSTR Perl","Perl");
   WSGIappLocaleSet()->setLocaleString("SJIS","P3:WSSTR Perl(DBG)","Perl(DBG)");
-  WSGIappLocaleSet()->setLocaleString("SJIS","f3:WSSTR Static option","DLLrh");
+  WSGIappLocaleSet()->setLocaleString("SJIS","f3:WSSTR Static option","N");
   WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Statically linked","X^eBbNN(DLL )");
   WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Dynamically linked","_Ci~bNN(DLL )");
-
