@@ -33,6 +33,7 @@
 #include <WSCindexForm.h>
 #include <WSCsform.h>
 #include <WSClist.h>
+#include <WSCtreeList.h>
 #include <WSCpopupMenu.h>
 #include <WSCbaseList.h>
 #include <WSDmouse.h>
@@ -115,6 +116,11 @@ void WSCinspector::setWorkWSNvalue(WSCulong val){
   }else{
     setFormVisible(4,False);
   }
+  if (val & 0x10){
+    setFormVisible(5,True);
+  }else{
+    setFormVisible(5,False);
+  }
 }
 
 void WSCinspector::getWorkWSNvalue(WSCulong* val){
@@ -161,9 +167,16 @@ void WSCinspector::setWorkWSNbarValue(char* data){
   // but _pos will not be freed.
   // so free _pos and _pos_bk
   delete _pos;
+  if (tmp.getWords(",") < 4){
+    long val = atol(tmp2);
+    char buffer[32];
+    sprintf(buffer,"%d",val+150);
+    tmp2 << "," << buffer;
+  }else{
+    tmp2 << "," << tmp.getWord(3,",");
+  }
   _pos = WSGFstrdup(tmp2.getString());
   _pos_bk = WSGFstrdup(_pos);
-
   WSCsform::setWorkWSNbarValue(_pos);
   update();
   if (_sform != NULL && _sform2 != NULL){
@@ -201,7 +214,9 @@ void WSCinspector::setWorkWSNbarValue(char* data){
   }
 }
 void WSCinspector::getWorkWSNbarValue(char** data){
-  WSCstring ret(_pos);
+  WSCstring tmp(_pos);
+  WSCstring ret = tmp.getWord(0,",");
+
   if (_sform != NULL){
     WSCstring tmp =  _sform->getProperty(WSNbarValue);
     if (!strcmp((char*)tmp,"")){
@@ -222,6 +237,14 @@ void WSCinspector::getWorkWSNbarValue(char** data){
   }else{
     ret << "," << "150";
   }
+  if (tmp.getWords(",") < 2){
+    long val = atol(ret);
+    char buffer[64];
+    sprintf(buffer,"%d",val + 150);
+    ret << "," << buffer;
+  }else{
+    ret << "," << tmp.getWord(1,",");
+  }
   delete _pos_bk;
   _pos_bk = WSGFstrdup(ret.getString());
   *data = _pos_bk;
@@ -229,7 +252,7 @@ void WSCinspector::getWorkWSNbarValue(char** data){
 
 long WSCinspector::initialize(){
   WSCsform::initialize();
-  setProperty(WSNbarValue,"150");
+  setProperty(WSNbarValue,"150,300");
 
   _dfform = new WSCfform(this,(WSCstring)"is-a1-" + getInstanceName());
   _dfform->setInternalObject(True);
@@ -296,6 +319,70 @@ long WSCinspector::initialize(){
   _dir_tree->addProcedure(opf9);
 
 
+
+  _cfform = new WSCfform(this,(WSCstring)"is-c1-" + getInstanceName());
+  _cfform->setInternalObject(True);
+  _cfform->initialize();
+  _cfform->setUserData("inspector",this);
+  _cfform->setProperty(WSNx,1);
+  _cfform->setProperty(WSNy,35);
+  _cfform->setPropertyV(WSNwidth,     (WSCushort)50 );
+  _cfform->setPropertyV(WSNheight,     (WSCushort)50 );
+  _cfform->setProperty(WSNbackColor,WS_DF_DARKBACKCOLOR);
+  _cfform->setProperty(WSNorientation,WS_HORIZONTAL);
+  _cfform->setProperty(WSNshadowThickness,0);
+  _cfform->setProperty(WSNbarThickness,14);
+  _cfform->setProperty(WSNtitleString,"Classes");
+  _cfform->setProperty(WSNmargin,20);
+  _cfform->setVisible(True);
+
+  WSCprocedure* copf5 = new WSCprocedure("op0",WSEV_STATUS_CH);
+  copf5->setFunction(_float_work5,"WSCinspector::_float_work5");
+  _cfform->addProcedure(copf5);
+
+  WSCprocedure* copf6 = new WSCprocedure("op0",WSEV_VISIBLE_CH);
+  copf6->setFunction(_float_vis_work,"WSCinspector::_float_vis_work");
+  _cfform->addProcedure(copf6);
+
+
+  ebt = new WSCvendbtn(_cfform,(WSCstring)"is-lt-" + getInstanceName());
+  ebt->initialize();
+  ebt->setProperty(WSNwidth,15);
+  ebt->setProperty(WSNheight,15);
+  ebt->setProperty(WSNindicatorSize,13);
+  ebt->setProperty(WSNanchorRightFlag,True);
+  ebt->setProperty(WSNanchorRight,2);
+  ebt->setProperty(WSNanchorTopFlag,True);
+  ebt->setProperty(WSNanchorTop,2);
+  WSGFsetMargin(ebt,0);
+  ebt->setVisible(True);
+
+  _class_list = new WSCtreeList(_cfform,(WSCstring)"is-clist-" + getInstanceName());
+  _class_list->setInternalObject(True);
+  _class_list->initialize();
+//  _list->setPropertyV(WSNx,     (short)0 );
+//  _list->setPropertyV(WSNy,     (short)0 );
+  _class_list->setProperty(WSNbackColor,WS_DF_DARKBACKCOLOR);
+  _class_list->setPropertyV(WSNtype,(WSCuchar)WS_TREE);
+  _class_list->setPropertyV(WSNuseIcon,(WSCbool)True);
+  _class_list->setPropertyV(WSNreverseSelect,(WSCbool)False);
+  _class_list->setProperty(WSNpixmapStyle,WS_DYNAMIC_PIXMAP);
+  _class_list->setVisible(True);
+  _class_list->setUserData("inspector",this);
+  _class_list->setProperty(WSNanchorTopFlag,True);
+  _class_list->setProperty(WSNanchorTop,18);
+  _class_list->setProperty(WSNanchorBottomFlag,True);
+  _class_list->setProperty(WSNanchorBottom,0);
+  _class_list->setProperty(WSNanchorLeftFlag,True);
+  _class_list->setProperty(WSNanchorLeft,0);
+  _class_list->setProperty(WSNanchorRightFlag,True);
+  _class_list->setProperty(WSNanchorRight,0);
+  _class_list->setProperty(WSNdataSource,WS_DATA_SOURCE_FILE);
+  _class_list->setProperty(WSNdataSourceName,"$(WSDIR)/sys/data/classes.dat");
+
+
+
+
   _sform = new WSCsform(this,(WSCstring)"is-sf1-" + getInstanceName());
   _sform->setInternalObject(True);
   _sform->initialize();
@@ -832,6 +919,9 @@ WSCbase* WSCinspector::getForm3(){
 WSCbase* WSCinspector::getForm4(){
   return _mfform;
 }
+WSCbase* WSCinspector::getForm5(){
+  return _cfform;
+}
 
 void WSCinspector::_adjust_forms(){
   if (WSGIappDev()->getGuiPolicy() & WS_POLICY_OTHER){
@@ -938,6 +1028,15 @@ void WSCinspector::_adjust_forms(){
     setManaged(_dfform,True);
     form1_managed = False;
   }
+  long form5_managed = True;
+  fl = _cfform->getProperty(WSNvis);
+  if (fl == False || _cfform->getFloated() == True){
+    setManaged(_cfform,False);
+    form5_managed = False;
+  }else{
+    setManaged(_cfform,True);
+    form5_managed = False;
+  }
 }
 
 void WSCinspector::setFormVisible(long no,WSCbool fl){
@@ -973,6 +1072,14 @@ void WSCinspector::setFormVisible(long no,WSCbool fl){
       _mfform->setVisible(True);
     }
     _adjust_forms();
+  }else
+  if (no == 5){
+    if (fl == False){
+      _cfform->setVisible(False);
+    }else{
+      _cfform->setVisible(True);
+    }
+    _adjust_forms();
   }
 }
 WSCulong WSCinspector::getFormVisible(){
@@ -993,6 +1100,10 @@ WSCulong WSCinspector::getFormVisible(){
   if (fl != False){
     ret |= 0x8;
   }
+  fl = _cfform->getProperty(WSNvis);
+  if (fl != False){
+    ret |= 0x10;
+  }
   return ret;
 }
 void WSCinspector::setForm4Client(WSCbase* cl){
@@ -1073,8 +1184,6 @@ void WSCinspector::_float_work3(WSCbase* fform){
     obj->_dir_tree->setProperty(WSNanchorRight,0);
   }
 }
-
-
 void WSCinspector::_float_work2(WSCbase* fform){
   WSCinspector* obj = (WSCinspector*)fform->getUserData("inspector");
   WSCbool floated = obj->_ifform->getFloated();
@@ -1115,6 +1224,31 @@ void WSCinspector::_float_work2(WSCbase* fform){
     obj->_list->setProperty(WSNanchorRight,0);
   }
 }
+
+void WSCinspector::_float_work5(WSCbase* fform){
+  WSCinspector* obj = (WSCinspector*)fform->getUserData("inspector");
+  WSCbool floated = obj->_cfform->getFloated();
+  obj->_adjust_forms();
+
+  if (floated == True){
+    fform->setProperty(WSNshadowThickness,1);
+    obj->_class_list->setProperty(WSNanchorBottomFlag,True);
+    obj->_class_list->setProperty(WSNanchorBottom,15);
+    obj->_class_list->setProperty(WSNanchorLeftFlag,True);
+    obj->_class_list->setProperty(WSNanchorLeft,2);
+    obj->_class_list->setProperty(WSNanchorRightFlag,True);
+    obj->_class_list->setProperty(WSNanchorRight,2);
+  }else{
+    fform->setProperty(WSNshadowThickness,0);
+    obj->_class_list->setProperty(WSNanchorBottomFlag,True);
+    obj->_class_list->setProperty(WSNanchorBottom,0);
+    obj->_class_list->setProperty(WSNanchorLeftFlag,True);
+    obj->_class_list->setProperty(WSNanchorLeft,0);
+    obj->_class_list->setProperty(WSNanchorRightFlag,True);
+    obj->_class_list->setProperty(WSNanchorRight,0);
+  }
+}
+
 void WSCinspector::_float_work(WSCbase* fform){
   WSCinspector* obj = (WSCinspector*)fform->getUserData("inspector");
   WSCbool floated = obj->_fform->getFloated();
@@ -1424,7 +1558,8 @@ void WSCinspector::_lb_activate_work(WSCbase* label){
     }
   }
   ins->_list2->updateList();
-  ins->_list2->redraw();
+//  ins->_list2->redraw(); // not applear the contents of the list..
+  ins->_list2->cdraw();
 //printf("WSCinspector::_lb_activate_work done..\n");
 }
 
@@ -1914,6 +2049,21 @@ void WSCinspector::setSelectIndexTab(long no){
 WSCbase* WSCinspector::getDirTree(){
   return _dir_tree;
 }
+WSCbase* WSCinspector::getClassList(){
+  return _class_list;
+}
 void WSCinspector::onGuiPolicyChanged(long policy){
   _adjust_forms();
 }
+WSCstring WSCinspector::getSelectedClassName(){
+  long pos1 = _class_list->getSelectedPos();
+  long pos2 = _class_list->getPreSelectedPos();
+  
+  WSCstring ret;
+  if (pos1 == pos2){
+    ret = _class_list->getSelectedItem();
+  }else{
+    ret = _class_list->getItem(pos2);
+  }
+  return ret;
+}
