@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -39,6 +39,7 @@
 #include <WSCmessageDialog.h>
 #include <WSCfileSelect.h>
 #include <WSCvtoggle.h>
+#include <WSCvradio.h>
 #include <WSDfile.h>
 #include <WSCballoonHelp.h>
 #include <WSCpopupMenu.h>
@@ -219,8 +220,8 @@ void WSCprocedureEditor::setWorkWSNheight(WSCushort data){
 }
 void WSCprocedureEditor::setWorkWSNshadowThickness(WSCuchar data){
   WSCform::setWorkWSNshadowThickness(data);
-  _list->setProperty(WSNshadowThickness,data);
-  _pmenu->setProperty(WSNshadowThickness,data);
+//  _list->setProperty(WSNshadowThickness,data);
+//  _pmenu->setProperty(WSNshadowThickness,data);
 }
 void WSCprocedureEditor::setWorkWSNclient(void* data){
   WSCbase* client = (WSCbase*)data;
@@ -921,6 +922,8 @@ WSCprocedure* WSCprocedureEditor::getProcedure(long no){
 }
 
 long WSCprocedureEditor::draw(){
+  return WSCform::draw();
+#if 0
   if (_no_refresh != False){
     WSCbase::update();
     setAbsoluteDraw(False);
@@ -984,6 +987,7 @@ long WSCprocedureEditor::draw(){
   }
   dev->endDraw();
   return WS_NO_ERR;
+#endif
 }
 
 
@@ -1003,8 +1007,8 @@ long WSCprocedureEditor::initialize(){
   for(i=0; i<4; i++){
     WSCvfbtn* btn = new WSCvfbtn(this,"cs-vfbtn");
     btn->initialize();
-    btn->setPropertyV(WSNx,(short)(i* 30));
-    btn->setPropertyV(WSNy,(short)(1));
+    btn->setPropertyV(WSNx,(short)(i* 30+_shadow_thick));
+    btn->setPropertyV(WSNy,(short)(1+_shadow_thick));
     btn->setPropertyV(WSNwidth,(WSCushort)(30));
     btn->setPropertyV(WSNheight,(WSCushort)(29));
     btn->setPropertyV(WSNlabelPixmap,pixmaps[i]);
@@ -1023,10 +1027,10 @@ long WSCprocedureEditor::initialize(){
   _list = new WSClist(this,"pe-area2");
   _list->initialize();
   _list->setInternalObject(True);
-  _list->setPropertyV(WSNx,     (short)0 );
-  _list->setPropertyV(WSNy,     (short)30 );
+  _list->setProperty(WSNx,     (short)0 );
+  _list->setProperty(WSNy,     (short)30 + _shadow_thick);
   _list->setPropertyV(WSNwidth, (WSCushort)(_w));
-  _list->setPropertyV(WSNheight,(WSCushort)(_h -30));
+  _list->setPropertyV(WSNheight,(WSCushort)(_h -32 - _shadow_thick*2));
   _list->setPropertyV(WSNworkWidth, (WSCushort)(WS_OLLB_W -20));
   _list->setPropertyV(WSNworkHeight,(WSCushort)1500);
   _list->setPropertyV(WSNscrollHeight,(WSCushort)5);
@@ -1238,7 +1242,8 @@ long WSCprocedureEditor::initialize(){
   dop2->setFunction(_dialog_src_work,"_dialog_src_work");
   _cbtn->addProcedure(dop2);
 
-  _use_file = new WSCvtoggle(_darea1,"ope-use_file");
+//  _use_file = new WSCvtoggle(_darea1,"ope-use_file");
+  _use_file = new WSCvradio(_darea1,"ope-use_file");
   _use_file->initialize();
   _use_file->setInternalObject(True);
   _use_file->setPropertyV(WSNx, (short)5);
@@ -1248,11 +1253,11 @@ long WSCprocedureEditor::initialize(){
   _use_file->setPropertyV(WSNlabelString, WSGFgettext("z3:WSSTR Internal"));
   _use_file->setPropertyV(WSNmarginLeft, (WSCuchar)10);
   _use_file->setPropertyV(WSNalignmentH, (WSCuchar)WS_LEFT);
-  _use_file->setPropertyV(WSNindicatorPixmap,WS_TG1_PIX);
-  _use_file->setPropertyV(WSNselectPixmap,WS_TG2_PIX);
-  _use_file->setPropertyV(WSNindicatorType,WS_IN);
+//  _use_file->setPropertyV(WSNindicatorPixmap,WS_TG1_PIX);
+//  _use_file->setPropertyV(WSNselectPixmap,WS_TG2_PIX);
+//  _use_file->setPropertyV(WSNindicatorType,WS_IN);
   _use_file->setPropertyV(WSNindicatorSize,(WSCuchar)16);
-  _use_file->setPropertyV(WSNshadowThickness,(WSCuchar)0);
+//  _use_file->setPropertyV(WSNshadowThickness,(WSCuchar)0);
   _use_file->setProperty(WSNbackColor,WS_DF_DARKBACKCOLOR);
   _use_file->setProperty(WSNbacktab,"pe-tif3");
   _use_file->setVisible(True);
@@ -1387,12 +1392,13 @@ void WSCprocedureEditor::_adjust(){
   if (_list == NULL){
     return;
   }
-  _list->setPropertyV(WSNwidth,(WSCushort)_w);
+  _list->setProperty(WSNx,_shadow_thick);
+  _list->setProperty(WSNwidth,_w - _shadow_thick*2);
 
-  if (_h > 30){
-    _list->setPropertyV(WSNheight,(WSCushort)(_h -30));
+  if (_h > 30 + _shadow_thick){
+    _list->setProperty(WSNheight,_h -32 - _shadow_thick*2);
   }else{
-    _list->setPropertyV(WSNheight,(WSCushort)(1));
+    _list->setProperty(WSNheight,1);
   }
 }
 void WSCprocedureEditor::createNewProc(){
@@ -1419,17 +1425,17 @@ void WSCprocedureEditor::onGuiPolicyChange(long policy){
       _fsbtn->setProperty(WSNgradation,WS_GR_NONE);
       _cbtn->setProperty(WSNgradation,WS_GR_NONE);
     }
+    if (policy & WS_POLICY_OTHER){
+      _darea1->setProperty(WSNy,0 );
+      _darea1->setProperty(WSNshadowThickness,0);
+    }else
     if (policy & WS_POLICY_ORIGINAL){
       _darea1->setProperty(WSNy,5 );
       _darea1->setProperty(WSNshadowThickness,1);
-//      _darea2->setProperty(WSNy,5);
-//      _darea2->setProperty(WSNshadowThickness,1);
     }else
     if (policy & WS_POLICY_WINDOWS){
       _darea1->setProperty(WSNy,0 );
       _darea1->setProperty(WSNshadowThickness,0);
-//      _darea2->setProperty(WSNy,0);
-//      _darea2->setProperty(WSNshadowThickness,0);
     }
     _dialog_resize_work((WSCbase*)_dialog1);
   }
