@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -480,11 +480,13 @@ void WSCbase::update(){
   }
   _update_registered = False;
   _geometry_changed = False;
+dbprintf("WSCbase::update() %s:%d %s updated...\n",__FILE__,__LINE__,getInstanceName());
 }
 void WSCbase::needUpdate(){
   if (_update_registered == False && _vis != False){
     _update_registered = True;
     WSGIappObjectList()->addNeedUpdate(this);
+dbprintf("WSCbase::needUpdate() %s:%d %s add update list...\n",__FILE__,__LINE__,getInstanceName());
   }
 }
 long WSCbase::delChild(WSCbase* child){
@@ -611,6 +613,27 @@ void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
   }
 
   if (diff_x != 0 || diff_y != 0){
+    WSCbool at = False;
+    WSCbool ab = False;
+    WSCbool al = False;
+    WSCbool ar = False;
+    if (base->existProperty(WSNanchorTopFlag) == True &&
+        (WSCbool)base->getProperty(WSNanchorTopFlag) == True){
+      at = True;
+    }
+    if (base->existProperty(WSNanchorBottomFlag) == True &&
+        (WSCbool)base->getProperty(WSNanchorBottomFlag) == True){
+      ab = True;
+    }
+    if (base->existProperty(WSNanchorLeftFlag) == True &&
+        (WSCbool)base->getProperty(WSNanchorLeftFlag) == True){
+      al = True;
+    }
+    if (base->existProperty(WSNanchorRightFlag) == True &&
+        (WSCbool)base->getProperty(WSNanchorRightFlag) == True){
+      ar = True;
+    }
+
     WSCbool refresh = False;
     if (base->getObjectType() & WS_TYPE_FORM){
     }else{
@@ -621,6 +644,9 @@ void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
     }
     switch(no){
     case 0:
+      if (at == True || al == True){
+        break;
+      }
       if (y -diff_y > -1 && h + diff_y > 0 && 
           x -diff_x > -1 && w + diff_x > 0 ){
         short dx = x - WSGFadjustNumber(x - diff_x,gx);
@@ -632,6 +658,9 @@ void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
       }
       break;
     case 1:
+      if (at == True){
+        break;
+      }
       if (y -diff_y > -1 && h + diff_y > 0){
         short dy = y - WSGFadjustNumber(y - diff_y,gy);
         base->setPropertyV(WSNy, (short)(WSGFadjustNumber(y - diff_y,gy)) );
@@ -639,6 +668,9 @@ void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
       }
       break;
     case 2:
+      if (at == True || ar == True){
+        break;
+      }
       if (y -diff_y > -1 && h + diff_y > 0){
         short dy = y - WSGFadjustNumber(y - diff_y,gy);
         base->setPropertyV(WSNy, (short)(WSGFadjustNumber(y - diff_y,gy)) );
@@ -649,11 +681,17 @@ void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
       }
       break;
     case 3:
+      if (ar == True){
+        break;
+      }
       if (x + w - diff_x < pw && w - diff_x > 0){ 
         base->setPropertyV(WSNwidth,(WSCushort)(WSGFadjustNumber(w -diff_x,gx)) );
       }
       break;
     case 4:
+      if (ab == True || ar == True){
+        break;
+      }
       if (x + w - diff_x < pw && w - diff_x > 0){ 
         base->setPropertyV(WSNwidth,(WSCushort)(WSGFadjustNumber(w -diff_x,gx)) );
       }
@@ -662,11 +700,17 @@ void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
       }
       break;
     case 5:
+      if (ab == True){
+        break;
+      }
       if (y + h - diff_y < ph && h - diff_y > 0){ 
         base->setPropertyV(WSNheight,(WSCushort)(WSGFadjustNumber(h -diff_y,gy)));
       }
       break;
     case 6:
+      if (ab == True || al == True){
+        break;
+      }
       if (x -diff_x > -1 && w + diff_x > 0){
         short dx = x - WSGFadjustNumber(x - diff_x,gx);
         base->setPropertyV(WSNx, (short)(WSGFadjustNumber(x - diff_x,gx)) );
@@ -677,6 +721,9 @@ void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
       }
       break;
     case 7:
+      if (al == True){
+        break;
+      }
       if (x -diff_x > -1 && w + diff_x > 0){
         short dx = x - WSGFadjustNumber(x - diff_x,gx);
         base->setPropertyV(WSNx, (short)(WSGFadjustNumber(x - diff_x,gx)) );
@@ -684,6 +731,9 @@ void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
       }
       break;
     case 8:
+      if (al == True || ar == True || at == True || ab == True){
+        break;
+      }
       if (x -diff_x > -1 && x -diff_x + w < pw){
         base->setPropertyV(WSNx, (short)(WSGFadjustNumber(x - diff_x,gx)) );
       }
@@ -1866,12 +1916,15 @@ void WSCbase::_exec_del_procedure(){
   return;
 }
 void WSCbase::execProcedure(long ev){
+dbprintf("WSCbase::execProcedure %s:%d %s start ev=0x%x\n",__FILE__,__LINE__,getInstanceName(),ev);
   if (ev == WSEV_EXPOSE && _expose_op == 0){
+dbprintf("WSCbase::execProcedure %s:%d %s done ev=0x%x\n",__FILE__,__LINE__,getInstanceName(),ev);
     return;
   }
   if (_prc_list != NULL){
     _exec_procedure(_prc_list,ev,False);
   }
+dbprintf("WSCbase::execProcedure %s:%d %s done2 ev=0x%x\n",__FILE__,__LINE__,getInstanceName(),ev);
   return;
 }
 void WSCbase::_exec_procedure(WSCprocedure* op){
@@ -1890,12 +1943,16 @@ void WSCbase::_exec_procedure(WSCprocedure* op){
   void (*proc)(WSCbase*); 
   proc = (void(*)(WSCbase*))op->getProc();
   if (proc != NULL){
+dbprintf("WSCbase::_exec_procedure %s:%d %s start op=%s\n",__FILE__,__LINE__,getInstanceName(),op->getFunctionName());
     proc(this);
+dbprintf("WSCbase::_exec_procedure %s:%d %s done op=%s\n",__FILE__,__LINE__,getInstanceName(),op->getFunctionName());
   }else{
     void(*hd)(char*,WSCbase*) =
                  (void(*)(char*,WSCbase*))WSGFgetProcedureHandler();
     if (hd != NULL){
+dbprintf("WSCbase::_exec_procedure %s:%d %s start op=%s\n",__FILE__,__LINE__,getInstanceName(),op->getFunctionName());
       hd(op->getFunctionName(),this);
+dbprintf("WSCbase::_exec_procedure %s:%d %s done op=%s\n",__FILE__,__LINE__,getInstanceName(),op->getFunctionName());
     }
   }
   if (WSGIappDev()->getTraceMode() != False && op->getInternal() == False){
@@ -2045,9 +2102,11 @@ void WSCbase::_exec_procedure(WSCprocedure** opl,char* opname){
   delete oplist2;
 }
 void WSCbase::execProcedure(char* opname){
+dbprintf("WSCbase::execProcedure %s:%d %s start opname=%s\n",__FILE__,__LINE__,getInstanceName(),opname);
   if (_prc_list != NULL){
     _exec_procedure(_prc_list,opname);
   }
+dbprintf("WSCbase::execProcedure %s:%d %s done opname=%s\n",__FILE__,__LINE__,getInstanceName(),opname);
   return;
 }
 long WSCbase::addProcedure(WSCprocedure* op){
@@ -2121,6 +2180,7 @@ long WSCbase::delProcedure(WSCprocedure* proc){
 long WSCbase::execEventProc(long ev,void* data){
 //DEVELOP///
 // makeing this procedure to use hash table
+dbprintf("WSCbase::execEventProc %s:%d %s start ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
   if (ev == WSEV_EXPOSE){
     if (data != NULL){
       WSCrect* area = (WSCrect*)data;
@@ -2129,6 +2189,7 @@ long WSCbase::execEventProc(long ev,void* data){
       if (_expose_op == 1){
         execProcedure(ev);
       }
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
       return WS_NO_ERR;
     }
   }else if (ev == WSEV_MOUSE_PRESS){
@@ -2136,6 +2197,7 @@ long WSCbase::execEventProc(long ev,void* data){
       WSCpoint* point = (WSCpoint*)data;
       onMousePress(point);
       execProcedure(ev);
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
       return WS_NO_ERR;
     }
   }else if (ev == WSEV_MOUSE_DOUBLE_CLICK){
@@ -2143,6 +2205,7 @@ long WSCbase::execEventProc(long ev,void* data){
       WSCpoint* point = (WSCpoint*)data;
       onMouseDoubleClick(point);
       execProcedure(ev);
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
       return WS_NO_ERR;
     }
   }else if (ev == WSEV_MOUSE_RELEASE){
@@ -2150,6 +2213,7 @@ long WSCbase::execEventProc(long ev,void* data){
       WSCpoint* point = (WSCpoint*)data;
       onMouseRelease(point);
       execProcedure(ev);
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
       return WS_NO_ERR;
     }
   }else if (ev == WSEV_MOUSE_IN){
@@ -2157,36 +2221,43 @@ long WSCbase::execEventProc(long ev,void* data){
       WSCpoint* point = (WSCpoint*)data;
       onMouseIn(point);
       execProcedure(ev);
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
       return WS_NO_ERR;
     }
   }else if (ev == WSEV_MOUSE_OUT){
     onMouseOut();
     execProcedure(ev);
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
     return WS_NO_ERR;
   }else if (ev == WSEV_MOUSE_MOVE){
     if (data != NULL){
       WSCpoint* point = (WSCpoint*)data;
       onMouseMove(point);
       execProcedure(ev);
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
       return WS_ERR;
     }
   }else if (ev == WSEV_RESIZE){
     WSCrect* rect = (WSCrect*)data;
     onResize(rect);
     execProcedure(ev);
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
     return WS_NO_ERR;
   }else if (ev == WSEV_GUI_POLICY_CH){
     long policy = (long)data;
     onGuiPolicyChange(policy);
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
     return WS_NO_ERR;
   } 
   execProcedure(ev);
+dbprintf("WSCbase::execEventProc %s:%d %s done ev=%d\n",__FILE__,__LINE__,getInstanceName(),ev);
   return WS_ERR;
 }
 void WSCbase::onMouseIn(WSCpoint*){}
 void WSCbase::onMouseOut(){}
 void WSCbase::onMouseMove(WSCpoint*){}
 void WSCbase::onFocusChange(WSCbool){}
+void WSCbase::onWindowFocusChange(WSCbool){}
 void WSCbase::onSpecialFocusChange(WSCbool){
   execProcedure(WSEV_SPECIAL_FOCUS_CH);
 }
