@@ -30,6 +30,7 @@
 #include <WSCbase.h>
 #include <WSClistData.h>
 #include <WSCRbaseList.h>
+#include <WSDappDev.h>
 
 class WSCbaseArray{
  public:
@@ -217,6 +218,10 @@ void WSCbaseList::addNeedUpdate(WSCbase* client){
 }
 void WSCbaseList::execInitialize(){
 dbprintf("WSCbaseList::execInitialize %s:%d start.\n",__FILE__,__LINE__);
+  WSCbool fl = WSGIappDev()->getUnderExecInitialize();
+  if (fl != False){
+    return;
+  }
   long i;
   long num = _need_init->getNum();
   if (num > 0){
