@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -1107,13 +1107,11 @@ long WSCstring::replaceString(const char* srcchar,const char* destchar,long num,
   long cnum = 0;
   WSCbool fl = False;
   for(i=0; i < len  ; i++){
-    if ( _str[i] == srcchar[0] ){
-      if (!strncmp(&_str[i],srcchar,(size_t)slen)){
-        cnum ++;
-        if (cnum <= num){
-          fl = True;
-          i += slen -1;
-        }
+    if (cnum < num && _str[i] == srcchar[0] && !strncmp(&_str[i],srcchar,(size_t)slen)){
+      cnum ++;
+      if (cnum <= num){
+        fl = True;
+        i += slen -1;
       }
     }
   }
@@ -1129,7 +1127,7 @@ long WSCstring::replaceString(const char* srcchar,const char* destchar,long num,
   long cnt = 0;
   long count = 0;
   for(i=0; i < len  ; i++){
-    if (_str[i] == srcchar[0] && !strncmp(&_str[i],srcchar,(size_t)slen)){
+    if (cnum < num && _str[i] == srcchar[0] && !strncmp(&_str[i],srcchar,(size_t)slen)){
       cnum ++;
       if (cnum <= num){
         strncpy(&new_str[cnt],destchar,(size_t)dlen);
@@ -1278,3 +1276,20 @@ void WSCstring::deleteChars(WSCulong char_pos,WSCulong len){
 long WSCstring::getEncoding(){
   return _get_encoding();
 }
+long WSCstring::setEncoding(long enc){
+  long encoding = enc;
+  if (encoding == WS_EN_DEFAULT){
+    encoding = WSGIappLocaleSet()->getDefaultEncoding();
+  }
+  if (encoding == WS_EN_LOCALE){
+    encoding = WSGIappLocaleSet()->getSystemLocaleEncoding();
+  } 
+  long encoding_bak = getEncoding();
+  if (encoding_bak == encoding){
+    return encoding;
+  }
+  char* new_str = _convert_string(_str,encoding_bak,encoding);
+  setString(new_str,encoding);
+  delete new_str;
+  return encoding_bak;
+}
