@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -27,6 +27,7 @@
 #include <WScom.h>
 #include <WSCvariant.h>
 #include <WSCstring.h>
+#include <WSCbase.h>
 
 
 WSCvariant::~WSCvariant(){
@@ -110,12 +111,19 @@ WSCvariant::WSCvariant(void* data,char* tname){
   _type = WSTvoidptr;
   _data = (void*)data;
   _data2 = NULL;
-  if (_type_name != NULL){
+  if (tname != NULL){
     _type_name = WSGFstrdup(tname);
   }else{
     _type_name = NULL;
   }
 }
+WSCvariant::WSCvariant(WSCbase* data){
+  _type = WSTvoidptr;
+  _data = (void*)data;
+  _data2 = NULL;
+  _type_name = WSGFstrdup("WSCbase*");
+}
+
 WSCvariant::WSCvariant(char* data){
   _type = WSTcharptr;
   WSCstring* str = new WSCstring;
@@ -428,6 +436,15 @@ double WSCvariant::getDouble(){
   return (double)0;
 }
 
+WSCbase* WSCvariant::getInstancePtr(){
+  if (_type == WSTvoidptr ){
+    if (!strcmp(_type_name,"WSCbase*")){
+      return (WSCbase*)_data;
+    }
+  }
+  return NULL;
+}
+
 void* WSCvariant::getVoidPtr(){
   if (_type == WSTchar || _type == WSTuchar ||
       _type == WSTshort || _type == WSTushort ||
@@ -590,6 +607,16 @@ void WSCvariant::setValue(void* val,char* cname){
     _type_name = WSGFstrdup(cname);
   }
 }
+void WSCvariant::setValue(WSCbase* val){
+  clear();
+  _data = (void*)val;
+  _type = WSTvoidptr;
+  if (_type_name != NULL){
+    delete _type_name;
+    _type_name = NULL;
+  }
+  _type_name = WSGFstrdup("WSCbase*");
+}
 void WSCvariant::setValue(float val){
   clear();
   memcpy(&_data,&val,sizeof(void*));
@@ -667,6 +694,10 @@ WSCvariant& WSCvariant::operator =(char* val){
   setValue(val);
   return *this;
 }
+WSCvariant& WSCvariant::operator =(WSCbase* val){
+  setValue(val);
+  return *this;
+}
 #if 0
 WSCvariant& WSCvariant::operator =(WSCstring val){
   setValue(val.getString());
@@ -710,6 +741,9 @@ WSCvariant::operator double (){
 WSCvariant::operator char* (){
   return getCharPtr();
 }
+WSCvariant::operator WSCbase* (){
+  return getInstancePtr();
+}
 #if 0
 WSCvariant::operator WSCstring(){
   WSCstring str;
