@@ -61,6 +61,7 @@ WSMFtrace("Error! too many instances of WSDappDev.\n");
   _mode = WS_MODE_NORMAL;
   _alt_context = NULL;
   _alt_context2 = NULL;
+  _under_exec_init = False;
 }
 
 WSDappDev::~WSDappDev(){
@@ -113,6 +114,7 @@ WSMFtrace("Error! No instance of WSDappDev exists.\n");
     exit(0);
     return WS_ERR;
   }
+  _under_exec_init = True;
   _init_executed = True;
   long num = getInitHandler()->getNum();
   long i;
@@ -125,6 +127,7 @@ WSMFtrace("Error! No instance of WSDappDev exists.\n");
   WSDmessage* msg1 = WSDmessage::getNewInstance();
   msg1->setupMessage(getInstanceName(),_trace_msg);
 dbprintf("WSDappDev::execInitHandler() %s:%d done. \n",__FILE__,__LINE__);
+  _under_exec_init = False;
   return WS_NO_ERR;
 }
 
@@ -352,3 +355,6 @@ WSCindexData* WSDappDev::getExtGuiPolicyList(){
   return &_ext_policy_list;
 #endif
 }
+WSCbool WSDappDev::getUnderExecInitialize(){
+  return _under_exec_init;
+}
