@@ -79,6 +79,7 @@ FILE* _ws_debug_fp = NULL;
 FILE* _ws_debug_fp = NULL;
 //FILE* _ws_debug_fp = stdout;
 #endif
+static WSCbool _ws_mem_debug_ = False;
 int _dbprintf_init(){
   if (getenv("WSDEBUG") != NULL && _ws_debug_fp == NULL){
 #ifndef BTRON
@@ -87,24 +88,26 @@ int _dbprintf_init(){
     _ws_debug_fp = stdout;
 #endif
   }
+  if (getenv("WSMEMDEBUG") != NULL){
+    _ws_mem_debug_ = True;
+  }
   return 0;
 };
 int _dbprintf(const char* format,...){
   if (_ws_debug_fp == NULL){
     return -1;
   }
-#if 1 //TEST
-
-  int i;
-  void* ptr[100];
-  for(i=0; i<100;i++){
-    ptr[i] = malloc(i*10);
-    memset(ptr[i],0,i*10);
+  if (_ws_mem_debug_ == True){
+    int i;
+    void* ptr[100];
+    for(i=0; i<100;i++){
+      ptr[i] = malloc(i*10);
+      memset(ptr[i],0,i*10);
+    }
+    for(i=0; i<100;i++){
+      free(ptr[i]);
+    }
   }
-  for(i=0; i<100;i++){
-    delete ptr[i];
-  }
-#endif //TEST
   int ret;
   va_list va;
   va_start(va,format);
