@@ -236,53 +236,93 @@ long WSCvlineGraph::draw(){
   }
   if (_stippled != False){
     if (_orientation == WS_VERTICAL){
+      long na_pt = -1;
       for(i=0; i<num; i++){
         WSCstring tmp = vlist.getWord(i,",");
+        if (!strcmp(tmp,"NA") || !strcmp(tmp,"na")){
+          if (na_pt+1 == i){
+            na_pt = i;
+            continue;
+          }
+          if (_rev == False){
+            points[i].x = interval*(i-1);
+            points[i].y = h -_lw/2;
+            points[i+1].x = interval*(na_pt+1);
+            points[i+1].y = h -_lw/2;
+          }else{
+            points[i].x = interval*(i-1);
+            points[i].y = _lw/2;
+            points[i+1].x = interval*(na_pt+1);
+            points[i+1].y = _lw/2;
+          }
+          dev->drawFillPoly(&points[na_pt+1],(i-(na_pt+1))+2);
+          na_pt = i;
+        }
         long val = atoi(tmp);
         if (_rev == False){
           points[i].x = interval*i;
           points[i].y =  h - h*val/100 +_lw/2;
         }else{
           points[i].x = interval*i;
-          points[i].y = _lw/2;
+          points[i].y = h*val/100 +_lw/2;
         }
       }
       if (_rev == False){
-        points[i].x = interval*num;
+        points[i].x = interval*i;
         points[i].y = h -_lw/2;
-        points[i+1].x = 0;
+        points[i+1].x = interval*(na_pt+1);
         points[i+1].y = h -_lw/2;
       }else{
-        points[i].x = interval*num;
+        points[i].x = interval*i;
         points[i].y = _lw/2;
-        points[i+1].x = 0;
+        points[i+1].x = interval*(na_pt+1);
         points[i+1].y = _lw/2;
       }
-      dev->drawFillPoly(points,num+2);
+      dev->drawFillPoly(&points[na_pt+1],(i-(na_pt+1))+2);
     }else{
+      long na_pt = -1;
       for(i=0; i<num; i++){
         WSCstring tmp = vlist.getWord(i,",");
+        if (!strcmp(tmp,"NA") || !strcmp(tmp,"na")){
+          if (na_pt+1 == i){
+            na_pt = i;
+            continue;
+          }
+          if (_rev == False){
+            points[i].x = w - _lw/2;
+            points[i].y = interval*(i-1);
+            points[i+1].x = w - _lw/2;
+            points[i+1].y = interval*(na_pt+1);
+          }else{
+            points[i].x = _lw/2;
+            points[i].y = interval*(i-1);
+            points[i].x = _lw/2;
+            points[i+1].y = interval*(na_pt+1);
+          }
+          dev->drawFillPoly(&points[na_pt+1],(i-(na_pt+1))+2);
+          na_pt = i;
+        }
         long val = atoi(tmp);
         if (_rev == False){
           points[i].x = w - w*val/100 + _lw/2;
           points[i].y = interval*i;
         }else{
-          points[i].x = _lw/2;
+          points[i].x = w*val/100 +_lw/2;
           points[i].y = interval*i;
         }
       }
       if (_rev == False){
         points[i].x = w - _lw/2;
-        points[i].y = interval*num;
+        points[i].y = interval*i;
         points[i+1].x = w - _lw/2;
-        points[i+1].y = 0;
+        points[i+1].y = interval*(na_pt+1);
       }else{
         points[i].x = _lw/2;
-        points[i].y = interval*num;
+        points[i].y = interval*i;
         points[i].x = _lw/2;
-        points[i+1].y = 0;
+        points[i+1].y = interval*(na_pt+1);
       }
-      dev->drawFillPoly(points,num+2);
+      dev->drawFillPoly(&points[na_pt+1],(i-(na_pt+1))+2);
     }
   }
   dev->setLineWidth(_lw);
@@ -291,31 +331,59 @@ long WSCvlineGraph::draw(){
   dev->setHatchPattern(0);
 
   if (_orientation == WS_VERTICAL){
+    long na_pt = -1;
     for(i=0; i<num; i++){
       WSCstring tmp = vlist.getWord(i,",");
+      if (!strcmp(tmp,"NA") || !strcmp(tmp,"na")){
+        if (na_pt+1 == i){
+          na_pt = i;
+          continue;
+        }
+        if (i-(na_pt+1) == 1){
+          dev->drawLine(points[na_pt+1].x,points[na_pt+1].y,
+                        points[na_pt+1].x+_lw,points[na_pt+1].y);
+        }else{
+          dev->drawLines(&points[na_pt+1],i-(na_pt+1));
+        }
+        na_pt = i;
+      }
       long val = atoi(tmp);
       if (_rev == False){
         points[i].x = interval*i;
         points[i].y =  h - h*val/100 +_lw/2;
       }else{
         points[i].x = interval*i;
-        points[i].y = _lw/2;
+        points[i].y = h*val/100 +_lw/2;
       }
     }
-    dev->drawLines(points,num);
+    dev->drawLines(&points[na_pt+1],i-(na_pt+1));
   }else{
+    long na_pt = -1;
     for(i=0; i<num; i++){
       WSCstring tmp = vlist.getWord(i,",");
+      if (!strcmp(tmp,"NA") || !strcmp(tmp,"na")){
+        if (na_pt+1 == i){
+          na_pt = i;
+          continue;
+        }
+        if (i-(na_pt+1) == 1){
+          dev->drawLine(points[na_pt+1].x,points[na_pt+1].y,
+                        points[na_pt+1].x,points[na_pt+1].y+_lw);
+        }else{
+          dev->drawLines(&points[na_pt+1],i-(na_pt+1));
+        }
+        na_pt = i;
+      }
       long val = atoi(tmp);
       if (_rev == False){
         points[i].x = w - w*val/100 + _lw/2;
         points[i].y = interval*i;
       }else{
-        points[i].x = _lw/2;
+        points[i].x = w*val/100 + _lw/2;
         points[i].y = interval*i;
       }
     }
-    dev->drawLines(points,num);
+    dev->drawLines(&points[na_pt+1],i-(na_pt+1));
   }
   delete points;
   dev->endDraw();
