@@ -594,6 +594,9 @@ long WSCdbMysqlRecord::moveLast()
 }
 long WSCdbMysqlRecord::setRowPos(WSCulong pos)
 {
+	for(int i = 0; i < _Cols; i++) {
+		memset(_fd[i].buff, '\0', _fd[i].buffLen);
+	}
 	_FetchRowPos = pos;
 	mysql_data_seek(_res_stmt, _FetchRowPos);
 	MYSQL_ROW row = mysql_fetch_row(_res_stmt);
@@ -907,7 +910,8 @@ void WSCdbMysqlRecord::getTableName(char* p, char* tbl, int size)
 						tbl[j] = '\0';
 						break;
 					}
-				} else {
+//				} else {
+				} else if(*s1 != '(' && *s1 != ')') {
 					tbl[j++] = *s1;
 				}
 			}
@@ -1004,15 +1008,18 @@ char* WSCdbMysqlRecord::decode(char* buf)
 }
 char* WSCdbMysqlRecord::getSelectSQL(const char* p, long rowiduse)
 {
-	char* buf = new char[strlen(p) + 128];
+	char* buf = new char[strlen(p) + 256];
 	char  buf1[7];
+	char  buf2[256];
 	buf1[6] = '\0';
 	if(rowiduse == 1) {
 		for(int i = 0; *p != '\0'; p++, i++) {
 			if(*p == ' ') {
 				strncpy(buf1, p, 6);
 				if(WSGFstricmp(buf1, " FROM ") == 0) {
-					strcpy(&buf[i], ",_rowid as _rowid_rowuse_");
+//					strcpy(&buf[i], ",_rowid as _rowid_rowuse_");
+					sprintf(buf2, ",%s._rowid as _rowid_rowuse_", _tableName);
+					strcpy(&buf[i], buf2);
 					strcat(buf, p);
 					break;
 				}
