@@ -90,7 +90,9 @@ long WSCdbPgsqlDatabase::open(char* host, char* uid, char* pwd, char* dbname, ch
 		sprintf(buf2, "FETCH ALL IN MYCURSOR_%d", _processid);
 		res = PQexec(_hconn, buf2);
 		if(!IS_PGSQL_ERROR(res)) {
-			encoding_conv(atoi((char*)PQgetvalue(res, 0, 0)));
+//			encoding_conv(atoi((char*)PQgetvalue(res, 0, 0)));
+			char* val = PQgetvalue(res, 0, 0);
+			encoding_conv((val != NULL ? atoi(val) : 0));
 		}
 		PQclear(res);
 		sprintf(buf2, "CLOSE MYCURSOR_%d", _processid);
@@ -401,7 +403,7 @@ long WSCdbPgsqlRecord::open(const char* stmt, short eCousor, short eAccess)
 	PGresult* res = NULL;
 	char*	buf;
 	char*	sql;
-	char	oid[80];
+	char	oid[256];
 	char	buf1[80];
 	char	buf2[256];
 	strncpy(buf1, stmt, 6);
@@ -430,7 +432,8 @@ long WSCdbPgsqlRecord::open(const char* stmt, short eCousor, short eAccess)
 					  "and a.attrelid = c.oid and attname='oid'", buf1, _tableName);
 		// oid item check
 		_oiduse = 0;
-		oid[0] = '\0';
+//		oid[0] = '\0';
+		strcpy(oid, "select ");
 		res = PQexec(_pDB->_hconn, buf2);
 		TRACE_U(("WSCdbPgsqlRecord::open oid %s", buf2));
 		if(!IS_PGSQL_ERROR(res)) {
@@ -439,7 +442,8 @@ long WSCdbPgsqlRecord::open(const char* stmt, short eCousor, short eAccess)
 			res = PQexec(_pDB->_hconn, buf2);
 			if(atoi((char*)PQgetvalue(res, 0, 0)) > 0) {
 				_oiduse = 1;
-				sprintf(oid, "select oid as oid_%s,", _CurrsorName);
+//				sprintf(oid, "select oid as oid_%s,", _CurrsorName);
+				sprintf(oid, "select %s.oid as oid_%s,", _tableName, _CurrsorName);
 				TRACE_U(("WSCdbPgsqlRecord::open oid use"));
 			}
 		}
@@ -985,7 +989,8 @@ void WSCdbPgsqlRecord::getTableName(char* p, char* tbl, int size)
 						tbl[j] = '\0';
 						break;
 					}
-				} else {
+//				} else {
+				} else if(*s1 != '(' && *s1 != ')') {
 					tbl[j++] = *s1;
 				}
 			}
