@@ -43,10 +43,14 @@ static _dll_init _execute_initialize;
 
 void _lang_init_proc(){
 #include "English.cpp"
+#ifndef _WSWIN32
 #include "Japanese.cpp"
+#endif
 #include "Japanese-sjis.cpp"
+#ifndef _WSWIN32
 #include "Japanese-utf8.cpp"
 #include "Korean.cpp"
+#endif
 }
 
 class _lang_init_{
@@ -108,7 +112,9 @@ WSCsheet::WSCsheet(WSCbase* base, char* objname) : WSCform(base, objname)
 	_dbSort3 = WSCSHEET_DB_SORT_ASC;
 	_dbFilter = WSGFstrdup("");
 	_dbStmtString = WSGFstrdup("");
-
+	_dbCellAutoResize = True;
+	_dbCellTitle = True;
+	
     WSMFpropertyCreateStart
     WSMFpropertyCreate(WSNrows, long, _rows, WSSrows);
     WSMFpropertyCreate(WSNcols, long, _cols, WSScols);
@@ -148,6 +154,21 @@ WSCsheet::WSCsheet(WSCbase* base, char* objname) : WSCform(base, objname)
     WSMFpropertySetSelection(WSRsort3, WSRsort3D);
     WSMFpropertyCreate(WSNfilter, char*, _dbFilter, WSSfilter);
     WSMFpropertyCreate(WSNsql, char*, _dbStmtString, WSSsql); 
+    WSMFpropertyCreate(WSNdbCellAutoResize, WSCbool, _dbCellAutoResize, WSSdbCellAutoResize);
+    WSMFpropertySetSelection(WSRbool1, WSRbool1D);
+    WSMFpropertyCreate(WSNdbCellTitle, WSCbool, _dbCellTitle, WSSdbCellTitle);
+    WSMFpropertySetSelection(WSRbool1, WSRbool1D);
+
+    WSMFaddExtTrigger(WSEV_SCR_MOUSE_PRESS,"SCR-MOUSE-PRESS");
+    WSMFaddExtTrigger(WSEV_SCR_MOUSE_RELEASE,"SCR-MOUSE-RELEASE");
+    WSMFaddExtTrigger(WSEV_SCR_MOUSE_MOVE,"SCR-MOUSE-MOVE");
+
+    WSMFaddTrigger(WSEV_ACTIVATE);
+    WSMFaddTrigger(WSEV_KEY_PRESS);
+    WSMFaddTrigger(WSEV_KEY_RELEASE);
+    WSMFaddTrigger(WSEV_KEY_HOOK);
+    WSMFaddTrigger(WSEV_VALUE_CH);
+
     WSMFpropertyCreateEnd
 }
 
@@ -182,7 +203,8 @@ WSMFproperty(WSCsheet, WSNsortItem3, char*, _dbSortItem3, WSGFstrdup(""));
 WSMFproperty(WSCsheet, WSNsort3, WSCuchar, _dbSort3, 0);
 WSMFproperty(WSCsheet, WSNfilter, char*, _dbFilter, WSGFstrdup(""));
 WSMFproperty(WSCsheet, WSNsql, char*, _dbStmtString, WSGFstrdup("")); 
-
+WSMFproperty(WSCsheet, WSNdbCellAutoResize, WSCbool, _dbCellAutoResize, True);
+WSMFproperty(WSCsheet, WSNdbCellTitle, WSCbool, _dbCellTitle, True);
 
 void WSCsheet::setWorkWSNrows(long val)
 {
@@ -340,7 +362,10 @@ void WSCsheet::setWorkWSNfilter(char* val){}
 void WSCsheet::getWorkWSNfilter(char**){}
 void WSCsheet::setWorkWSNsql(char* val){}
 void WSCsheet::getWorkWSNsql(char**){}
-
+void WSCsheet::setWorkWSNdbCellAutoResize(WSCbool val){}
+void WSCsheet::getWorkWSNdbCellAutoResize(WSCbool*){}
+void WSCsheet::setWorkWSNdbCellTitle(WSCbool val){}
+void WSCsheet::getWorkWSNdbCellTitle(WSCbool*){}
 
 
 WSCsheet::~WSCsheet()
@@ -371,6 +396,7 @@ WSCsheet::~WSCsheet()
 	if(_dbStmtString) {
 		delete[] _dbStmtString;
 	}
+
 }
 ///////////////////////////////////////////////////////////////////////////////
 // event
@@ -480,6 +506,31 @@ long WSCsheet::initialize()
 	op3->setFunction(onEditFocusChange, "onEditFocusChange");
 	_edit->addProcedure(op3);
 
+	WSCprocedure* op4 = new WSCprocedure("key-press", WSEV_KEY_PRESS);
+	op4->setInternal(True);
+	op4->setFunction(onEditKeyPress, "onEditKeyPress");
+	_edit->addProcedure(op4);
+
+	WSCprocedure* op5 = new WSCprocedure("key-release", WSEV_KEY_RELEASE);
+	op5->setInternal(True);
+	op5->setFunction(onEditKeyRelease, "onEditKeyRelease");
+	_edit->addProcedure(op5);
+
+	WSCprocedure* op6 = new WSCprocedure("key-hook", WSEV_KEY_HOOK);
+	op6->setInternal(True);
+	op6->setFunction(onEditKeyHook, "onEditKeyHook");
+	_edit->addProcedure(op6);
+
+	WSCprocedure* op7 = new WSCprocedure("activate", WSEV_ACTIVATE);
+	op7->setInternal(True);
+	op7->setFunction(onEditActivate, "onEditActivate");
+	_edit->addProcedure(op7);
+
+	WSCprocedure* op8 = new WSCprocedure("value-ch", WSEV_VALUE_CH);
+	op8->setInternal(True);
+	op8->setFunction(onEditValueChange, "onEditValueChange");
+	_edit->addProcedure(op8);
+
 	clear();
 
 	return WS_NO_ERR;
@@ -842,6 +893,7 @@ void WSCsheet::onSheetMouseMove(WSCbase* obj)
 		pt.x = (long)x;
 		pt.y = (long)y;
 		ss->onMouseMove(&pt);
+		ss->onScrMouseMove(&pt);
 	}
 }
 void WSCsheet::onSheetMousePress(WSCbase* obj)
@@ -855,6 +907,7 @@ void WSCsheet::onSheetMousePress(WSCbase* obj)
 		pt.x = (long)x;
 		pt.y = (long)y;
 		ss->onMousePress(&pt);
+		ss->onScrMousePress(&pt);
 	}
 }
 void WSCsheet::onSheetMouseRelease(WSCbase* obj)
@@ -868,9 +921,78 @@ void WSCsheet::onSheetMouseRelease(WSCbase* obj)
 		pt.x = (long)x;
 		pt.y = (long)y;
 		ss->onMouseRelease(&pt);
+		ss->onScrMouseRelease(&pt);
 	}
 }
-
+void WSCsheet::onScrMouseMove(WSCpoint* pt)
+{
+	execProcedure(WSEV_SCR_MOUSE_MOVE);
+}
+void WSCsheet::onScrMousePress(WSCpoint* pt)
+{
+	execProcedure(WSEV_SCR_MOUSE_PRESS);
+}
+void WSCsheet::onScrMouseRelease(WSCpoint* pt)
+{
+	execProcedure(WSEV_SCR_MOUSE_RELEASE);
+}
+void WSCsheet::onEditActivate(WSCbase* obj)
+{
+	WSCbase* parent = obj->getParent();
+	WSCbase* sheet = parent->getParent();
+	WSCsheet* ss = (WSCsheet*)sheet->cast("WSCsheet");
+	ss->onActivate();
+}
+void WSCsheet::onEditKeyPress(WSCbase* obj)
+{
+	WSCbase* parent = obj->getParent();
+	WSCbase* sheet = parent->getParent();
+	WSCsheet* ss = (WSCsheet*)sheet->cast("WSCsheet");
+	ss->onKeyPress(WSGIappKeyboard());
+}
+void WSCsheet::onEditKeyRelease(WSCbase* obj)
+{
+	WSCbase* parent = obj->getParent();
+	WSCbase* sheet = parent->getParent();
+	WSCsheet* ss = (WSCsheet*)sheet->cast("WSCsheet");
+	ss->onKeyRelease(WSGIappKeyboard());
+}
+void WSCsheet::onEditKeyHook(WSCbase* obj)
+{
+	WSCbase* parent = obj->getParent();
+	WSCbase* sheet = parent->getParent();
+	WSCsheet* ss = (WSCsheet*)sheet->cast("WSCsheet");
+	ss->onKeyHook(WSGIappKeyboard());
+}
+void WSCsheet::onEditValueChange(WSCbase* obj)
+{
+	WSCbase* parent = obj->getParent();
+	WSCbase* sheet = parent->getParent();
+	WSCsheet* ss = (WSCsheet*)sheet->cast("WSCsheet");
+	if(ss->_edit->getVisible()) {
+		ss->onValueChange();
+	}
+}
+void WSCsheet::onActivate()
+{
+	execProcedure(WSEV_ACTIVATE);
+}
+void WSCsheet::onKeyPress(WSDkeyboard* keyboard)
+{
+	execProcedure(WSEV_KEY_PRESS);
+}
+void WSCsheet::onKeyRelease(WSDkeyboard* keyboard)
+{
+	execProcedure(WSEV_KEY_RELEASE);
+}
+void WSCsheet::onKeyHook(WSDkeyboard* keyboard)
+{
+	execProcedure(WSEV_KEY_HOOK);
+}
+void WSCsheet::onValueChange()
+{
+	execProcedure(WSEV_VALUE_CH);
+}
 ///////////////////////////////////////////////////////////////////////////////
 // property function
 //
@@ -2112,6 +2234,7 @@ long WSCsheet::setFixedCellText(long col, long row, const WSCstring& text)
 {
 	WSCsheetCell* cell;
 	
+	WSCstring str = text;
 	if(col < 0 || row < 0) {
 		return WS_ERR;
 	}
@@ -2473,13 +2596,14 @@ void WSCsheet::focusCellVisible(long oldCol, long oldRow, long newCol, long newR
 			_edit->setPropertyV(WSNfont, (unsigned char)cell->fontno);
 
 			_edit->setFocus(False);
-			_edit->setVisible((getSelectCell() ? False : True));
+//			_edit->setVisible((getSelectCell() ? False : True));
 
 			if(fval) {
 				_edit->setSelect(0, (short)strlen(text.getString()));
 				_edit->setPropertyV(WSNcursorPos, (short)strlen(text.getString()));
 			}
 
+			_edit->setVisible((getSelectCell() ? False : True));
 			_edit->setFocus(True);
 		}
 	} else {
@@ -2522,7 +2646,7 @@ void WSCsheet::posMoveCell(WSCpoint* pt)
 		}
 	}
 }
-inline long WSCsheet::getWidthValue(long col)
+long WSCsheet::getWidthValue(long col)
 {
 	long* width = getWidthData(col);
 	if(!width) {
@@ -2530,7 +2654,7 @@ inline long WSCsheet::getWidthValue(long col)
 	}
 	return (*width == WSCSHEET_DEFAULT ? _colWidth : *width);
 }
-inline WSCsheetCell* WSCsheet::getCell(long col, long row, WSCbool alloc)
+WSCsheetCell* WSCsheet::getCell(long col, long row, WSCbool alloc)
 {
 	if(col < 0 || col >= getColumnCount()) {
 		return NULL;
@@ -2552,7 +2676,7 @@ inline WSCsheetCell* WSCsheet::getCell(long col, long row, WSCbool alloc)
 	}
 	return cell;
 }
-inline WSCsheetRow* WSCsheet::getRowData(long row)
+WSCsheetRow* WSCsheet::getRowData(long row)
 {
 	if(row < 0 || row >= _rowData.getNum()) {
 		return NULL;
@@ -2564,7 +2688,7 @@ inline WSCsheetRow* WSCsheet::getRowData(long row)
 	}
 	return rowdata;
 }
-inline long* WSCsheet::getWidthData(long col)
+long* WSCsheet::getWidthData(long col)
 {
 	if(col < 0 || col >= getColumnCount()) {
 		return NULL;
@@ -2868,7 +2992,7 @@ long WSCsheet::dbDataSet()
 	setEditEnabled(False);
 	setHorzAutoNumber(False);
 
-	clear(2, 2);
+//	clear(2, 2);
 
 	WSCdbRecord rs(_vdb);
 
@@ -2876,10 +3000,13 @@ long WSCsheet::dbDataSet()
 
 		rs.open(stmt);
 
-		clear(rs.getColCount() + 1, rs.getRowCount() + 1);
-
-		setFixedCelldbItem(&rs);
+		setColumnCount(rs.getColCount() + getFixedColumnCount()+1);
+		dataClear(rs.getColCount() + getFixedColumnCount(), rs.getRowCount() + getFixedRowCount());
 
+		if(_dbCellTitle) {
+			setFixedCelldbItem(&rs);
+		}
+		
 		WSCstring str;
 		char* val = new char[32767*2];
 		long col = 0;
@@ -2892,10 +3019,12 @@ long WSCsheet::dbDataSet()
 				rs.getColStringValue(col, val);
 				setCellText(col + fixedCols, row, val);
 
-				str = val;
-				width = getColumnWidth(col + fixedCols);
-				if(width < (font->getStringWidth(&str)+2)) {
-					setColumnWidth(col + fixedCols, font->getStringWidth(&str)+2);
+				if(_dbCellAutoResize) {
+					str = val;
+					width = getColumnWidth(col + fixedCols);
+					if(width < (font->getStringWidth(&str)+4)) {
+						setColumnWidth(col + fixedCols, font->getStringWidth(&str)+4);
+					}
 				}
 			}
 			row++;
@@ -2904,6 +3033,8 @@ long WSCsheet::dbDataSet()
 		rs.close();
 
 		delete[] val;
+	} else {
+		dataClear();
 	}
 	adjustScrollBar();
 
@@ -2913,3 +3044,37 @@ long WSCsheet::dbDataSet()
 
 	return WS_NO_ERR;
 }
+long WSCsheet::dataClear(long col, long row)
+{
+	WSCbool ref = getNoRefresh();
+	
+	setNoRefresh(True);
+
+	setRowCount(row);
+	setColumnCount(col);
+
+	setStartCol(1);
+	setEndCol(col);
+	setStartRow(1);
+	setEndRow(row);
+	setSelectCell(True);
+	setText("");
+	setSelectCell(False);
+	
+	_topVisibleRow = _fixedRows;
+	_topVisibleCol = _fixedCols;
+
+	_focusRow = 1;
+	_focusCol = 1;
+	_startRow = _focusRow;
+	_startCol = _focusCol;
+	_endRow = _focusRow;
+	_endCol = _focusCol;
+	_selectCell = False;
+	
+	setNoRefresh(ref);
+	
+	draw();
+
+	return WS_NO_ERR;
+}
