@@ -514,6 +514,8 @@ dbprintf("WndProc %s:%d done11\n",__FILE__,__LINE__);
     return ret1;
   }
 dbprintf("WndProc %s:%d done12\n",__FILE__,__LINE__);
+  WSGIappObjectList()->execInitialize();
+  WSGIappObjectList()->execUpdate();
   return 0;
 #if 0
   switch(message){
