@@ -176,7 +176,7 @@ WSMFtrace("WSDwinExecute::execute exename=NULL!!! XZZg1 return.\n");
     return WS_ERR;
   }
 WSMFtrace("WSDwinExecute::execute #%s# dir=#%s#  XXZZg1\n",exename,(char*)_dir_name);
-printf("WSDwinExecute::execute #%s# dir=#%s#  XXZZg1\n",exename,_dir_name.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
+//printf("WSDwinExecute::execute #%s# dir=#%s#  XXZZg1\n",exename,_dir_name.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
   PROCESS_INFORMATION pi;
   STARTUPINFO si;
   ZeroMemory(&si,sizeof(STARTUPINFO));
@@ -199,7 +199,7 @@ printf("WSDwinExecute::execute #%s# dir=#%s#  XXZZg1\n",exename,_dir_name.getStr
     while( dname.replaceString("/","\\",0));
     BOOL fl = SetCurrentDirectory(dname.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
 WSMFtrace("WSDwinExecute::execute2 dir=#%s#  XXZZg1\n",dname.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
-printf("WSDwinExecute::execute2 dir=#%s#  XXZZg1\n",dname.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
+//printf("WSDwinExecute::execute2 dir=#%s#  XXZZg1\n",dname.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
     if (fl == FALSE){
       return WS_ERR;
     }
