@@ -1060,6 +1060,8 @@ long WSDwindraw::drawImage(short x,short y,WSCushort w,WSCushort h,WSDimage* ima
         StretchBlt(_hdc,dx,dy,dw,dh,mdc,dx -x -xoff,dy-y-yoff,iw,ih,SRCCOPY);
       }else{
         StretchBlt(_hdc,dx,dy,dw,dh,mdc2,dx -x -xoff,dy-y-yoff,iw,ih,SRCAND);
+        BitBlt(mdc2,0,0,iw,ih,mdc2,0,0,DSTINVERT);
+        BitBlt(mdc,0,0,iw,ih,mdc2,0,0,SRCAND);
         StretchBlt(_hdc,dx,dy,dw,dh,mdc,dx -x -xoff,dy-y-yoff,iw,ih,SRCPAINT);
       }
     }else{
@@ -1067,6 +1069,10 @@ long WSDwindraw::drawImage(short x,short y,WSCushort w,WSCushort h,WSDimage* ima
         BitBlt(_hdc,dx,dy,dw,dh,mdc,dx -x -xoff,dy -y -yoff,SRCCOPY);
       }else{
         BitBlt(_hdc,dx,dy,dw,dh,mdc2,dx -x -xoff,dy -y -yoff,SRCAND);
+        WSCulong iw = image->getImageWidth();
+        WSCulong ih = image->getImageHeight();
+        BitBlt(mdc2,0,0,iw,ih,mdc2,0,0,DSTINVERT);
+        BitBlt(mdc,0,0,iw,ih,mdc2,0,0,SRCAND);
         BitBlt(_hdc,dx,dy,dw,dh,mdc,dx -x -xoff,dy -y -yoff,SRCPAINT);
       }
     }
@@ -1169,6 +1175,8 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
       StretchBlt(_hdc,dx,dy,dw,dh,mdc,dx -x +sx,dy -y +sy,iw,ih,SRCCOPY);
     }else{
       StretchBlt(_hdc,dx,dy,dw,dh,mdc2,dx -x +sx,dy -y +sy,iw,ih,SRCAND);
+      BitBlt(mdc2,0,0,iw,ih,mdc2,0,0,DSTINVERT);
+      BitBlt(mdc,0,0,iw,ih,mdc2,0,0,SRCAND);
       StretchBlt(_hdc,dx,dy,dw,dh,mdc,dx -x +sx,dy -y +sy,iw,ih,SRCPAINT);
     }
   }else{
@@ -1176,6 +1184,10 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
       BitBlt(_hdc,dx,dy,dw,dh,mdc,dx -x +sx,dy -y +sy,SRCCOPY);
     }else{
       BitBlt(_hdc,dx,dy,dw,dh,mdc2,dx -x +sx,dy -y +sy,SRCAND);
+      WSCulong iw = image->getImageWidth();
+      WSCulong ih = image->getImageHeight();
+      BitBlt(mdc2,0,0,iw,ih,mdc2,0,0,DSTINVERT);
+      BitBlt(mdc,0,0,iw,ih,mdc2,0,0,SRCAND);
       BitBlt(_hdc,dx,dy,dw,dh,mdc,dx -x +sx,dy -y +sy,SRCPAINT);
     }
   }
