@@ -121,8 +121,8 @@ void XUInit()
   }else{
     xu_locale_encoding = XU_CONV_LOCALE;
   }
-printf("XXZZlang 0x%x\n",GetSystemDefaultLangID());
-printf("XXZZlang2 0x%x\n",GetSystemDefaultLCID());
+//printf("XXZZlang 0x%x\n",GetSystemDefaultLangID());
+//printf("XXZZlang2 0x%x\n",GetSystemDefaultLCID());
 #endif
   long lid = GetSystemDefaultLCID();
   if ((lid & 0x3ff) == LANG_JAPANESE){
