@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -60,7 +60,7 @@
 #include <advance/WSCinspector.h>
 #include <advance/WSCprojectEditor.h>
 #include <advance/WSCobjectBox.h>
-#include <advance/WSCprocessBox.h>
+#include <advance/WSCprocessForm.h>
 #include <advance/WSCcolorSelect.h>
 #include <advance/WSadcom.h>
 
@@ -88,7 +88,8 @@ WSCbaseDialog*     objsearchwz;
 WSCform*           toolbar;
 WSCpopupMenu*      popupmenu;
 WSCpopupMenu*      popupmenu2;
-WSCprocessBox*     procbox;
+//WSCprocessBox*     procbox;
+WSCprocessForm*     procform;
 WSClistData        selected_clients;
 WSClistData        copy_clients;
 WSClistData        winlist;
@@ -138,13 +139,27 @@ long create_proc_for_template(char* pname,char* base_cname){
   WSCstring procstr;
   WSCstring pname2;
   pname2 << pname;
+  WSCstring fpname;
+  fpname << pname;
   if (pe->getLanguage() == WS_LANG_RUBY){
+    if (pname2.isExist(".cpp") != -1){
+      pname2.replaceString(".cpp","",1);
+      fpname.replaceString(".cpp",".rb",1);
+    }
     pname2.replaceString(".rb","",1);
   }else
   if (pe->getLanguage() == WS_LANG_PYTHON){
+    if (pname2.isExist(".cpp") != -1){
+      pname2.replaceString(".cpp","",1);
+      fpname.replaceString(".cpp",".py",1);
+    }
     pname2.replaceString(".py","",1);
   }else
   if (pe->getLanguage() == WS_LANG_PERL){
+    if (pname2.isExist(".cpp") != -1){
+      pname2.replaceString(".cpp","",1);
+      fpname.replaceString(".cpp",".pl",1);
+    }
     pname2.replaceString(".pl","",1);
   }else{
     pname2.replaceString(".cpp","",1);
@@ -168,7 +183,7 @@ long create_proc_for_template(char* pname,char* base_cname){
     WSGFclassProcedureCreate(&procstr,pname2,NULL,base_cname);
   }
   WSCstring fname;
-  fname << get_project_dir() << "/" << pname;
+  fname << get_project_dir() << "/" << fpname;
 
   WSCbool fl = WSGFcheckExistFile((char*)fname);
 
@@ -419,6 +434,7 @@ extern void _create_win_tracewin();
   WSCstring defprj;
   defprj << "$(WSDIR)/sys/data/" << WSGIappLocaleSet()->getDefaultLocaleName()
          << "/default.prj";
+  pe->setDefaultProjectName(defprj);
   pe->open(defprj);
 #if MSW
   long ret = pe->open_global("$(WINDIR)/.wsbuilderrc");
@@ -481,12 +497,26 @@ extern void create_objsearchwz_dialog();
   pmop->setFunction(idel_work2,"idel_work2");
   popupmenu->addProcedure(pmop);
 
-  procbox = new WSCprocessBox(NULL,"procbox");
-  procbox->initialize();
-  WSGFsetGeometry(procbox,100,100,400,300);
+//  procbox = new WSCprocessBox(NULL,"procbox");
+//  procbox->initialize();
+//  WSGFsetGeometry(procbox,100,100,400,300);
+  procform = new WSCprocessForm(inspector->getForm4(),"procform");
+  procform->initialize();
+  procform->setProperty(WSNbackColor,WS_DF_DARKBACKCOLOR);
+  procform->setPropertyV(WSNusePixmap,(WSCbool)True);
+  procform->setVisible(True);
+//  procform->setProperty(WSNshadowThickness,0);
+  inspector->setForm4Client(procform);
+
+extern void build_btn_sensitive_ch(WSCbase*);
+
+  WSCprocedure* pfop = new WSCprocedure("activate",WSEV_ACTIVATE);
+  pfop->setFunction(build_btn_sensitive_ch,"build_btn_sensitive_ch");
+  procform->addProcedure(pfop);
+
 
 //  WSCtextField* mtext = procbox->getTextField();
-  WSCbase* mtext = procbox->getTextField()->getTextFrame();
+  WSCbase* mtext = procform->getTextFrame();
   extern void error_editor_open(WSCbase*);
   WSCprocedure* mtop = new WSCprocedure("EDITOR OPEN",WSEV_MOUSE_DOUBLE_CLICK);
 //  WSCprocedure* mtop = new WSCprocedure("EDITOR OPEN",WSEV_MOUSE_PRESS);
@@ -566,7 +596,6 @@ extern void del_instance(WSCbase*);
 extern void load_window_style();
   load_window_style();
 
-  mainwindow->setVisible(True);
 extern void adjust_mainwindow(WSCbase*);
   adjust_mainwindow(mainwindow);  
   //ѥեȤȤ᤹
@@ -580,7 +609,7 @@ extern long check_name_strings(char*,WSCbase*);
 extern void _gui_policy_change();
   _gui_policy_change();
 
-extern void load_complete_lib_name(char*);
+extern long load_complete_lib_name(char*);
   load_complete_lib_name(
      WSGIappFileSystem()->adjustFileName("$(WSDIR)/sys/config/libname"));
 
@@ -633,7 +662,11 @@ extern long load_winfiles(char*,WSClistData*);
 #endif
       WSGIappColorSelect()->load((char*)fname);
     }
+extern void setup_buildbtn();
+    setup_buildbtn();
   }
+  mainwindow->setVisible(True);
+
 };
 
 void _gui_policy_change(){
