@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -531,9 +531,7 @@ long WSDxformDev::destroyWindow(){
     XtRemoveCallback(_widget,XtNdestroyCallback,_evh_delete2,this);
     XtDestroyWidget(_widget);
   }
-  _pwidget = 0;
-  _widget = 0;
-  setInitialized(False);
+  _clear_widget();
   return WS_NO_ERR;
 }
 
@@ -802,9 +800,7 @@ void WSDxformDev::_evh_delete2(Widget w,void* ptr,void*){
    if (dev->_widget != w){
      return;
    }
-   dev->_pwidget = 0;
-   dev->_widget = 0;
-   dev->setInitialized(False);
+   dev->_clear_widget();
 }
 
 void WSDxformDev::_evh_dummy(Widget ,XtPointer ,XEvent* ev,WSCbool*){
@@ -833,6 +829,11 @@ long WSDxformDev::lower(){
   }
   return WS_ERR;
 }
+void WSDxformDev::_clear_widget(){
+  _pwidget = 0;
+  _widget = 0;
+  setInitialized(False);
+}
 void WSDxformDev::clearChildWidgets(){
   WSCbase* client = getAttachedClient();
   if (client != NULL){
@@ -849,7 +850,5 @@ void WSDxformDev::clearChildWidgets(){
       }
     }
   }
-  _pwidget = 0;
-  _widget = 0;
-  setInitialized(False);
+  _clear_widget();
 }
