@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -43,8 +43,9 @@ extern void* dlsym(void*,char* procn);
 #include <x11/WSDxcolor.h>
 
 long WSGFxBufToPixmap(Display* display,Window window,GC gc,unsigned char *buf,Pixmap* pixmap,long width,long height,long* vw,long* vh);
-long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pixmap* pixmap,long* w,long* h);
-long WSGFxBmpReadFileToPixmap(Display* display,Window window,GC gc,char* filename,Pixmap* pixmap,long* w,long* h);
+long WSGFxBufToBitmap(Display* display,Window window,GC gc,unsigned char *buf,Pixmap* pixmap,long width,long height,long* vw,long* vh);
+long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pixmap* pixmap,Pixmap* pixmap2,long* w,long* h);
+long WSGFxBmpReadFileToPixmap(Display* display,Window window,GC gc,char* filename,Pixmap* pixmap,Pixmap* pixmap2,long* w,long* h);
 
 WSMFclassInit(WSDximage,WSDimage);
 
@@ -220,6 +221,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.so is invalid. \nso, j
   }else if (in.isExist(".png") != -1 || in.isExist(".PNG") != -1){
 //WSMFtrace("WSDximage::initialize %s\n",in.getString());
      Pixmap pixmap_file;
+     Pixmap pixmap_file2;
      long width = _w;
      long height = _h;
      char* load_file_name = in.getString();
@@ -228,7 +230,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.so is invalid. \nso, j
      GC gc = WSGIxwinAppDev()->appGC2();
      static void* dl = NULL;
      static long dl_init = 0;
-     static long (*fn)(Display*,Window,GC,char*,Pixmap*,long*,long*) = NULL;
+     static long (*fn)(Display*,Window,GC,char*,Pixmap*,Pixmap*,long*,long*) = NULL;
 
      if (dl_init == 0){
 #ifndef MacOS
@@ -250,7 +252,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library png.so open error. \nso, j
 WSMFtrace("ERROR. in WSDximage::initialize(). Library png.bundle open error. \nso, jpeg image can not support...\n");
 #endif //MacOS
        }else{
-         fn = (long (*)(Display*,Window,GC,char*,Pixmap*,long*,long*))
+         fn = (long (*)(Display*,Window,GC,char*,Pixmap*,Pixmap*,long*,long*))
                 dlsym(dl,"PngReadFileToPixmap");
          if (fn == NULL){
 WSMFtrace("ERROR. in WSDximage::initialize(). Library png.so is invalid. \nso, jpeg image can not support...\n");
@@ -259,13 +261,13 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library png.so is invalid. \nso, j
      }
      if (fn != NULL){
        long reti = fn( app->display(), XtWindow(app->appWidget()),gc,
-                       load_file_name, &pixmap_file, &width,&height);
+                       load_file_name, &pixmap_file,&pixmap_file2, &width,&height);
 
        if (reti == 0){
          setImageWidth(width);
          setImageHeight(height);
          setValue1((long)pixmap_file);
-         setValue2((long)0);
+         setValue2((long)pixmap_file2);
        }else{
 //WSMFtrace("ERROR. WSDximage::initialize file open error. file=%s\n",load_file_name);
        }
@@ -274,6 +276,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library png.so is invalid. \nso, j
   }else if (in.isExist(".bmp") != -1 || in.isExist(".BMP") != -1){
 //WSMFtrace("WSDximage::initialize %s\n",in.getString());
      Pixmap pixmap_file;
+     Pixmap pixmap_file2;
      long width = _w;
      long height = _h;
      char* load_file_name = in.getString();
@@ -283,13 +286,13 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library png.so is invalid. \nso, j
 
      long reti = WSGFxBmpReadFileToPixmap( app->display(),
                        XtWindow(app->appWidget()),gc,
-                       load_file_name, &pixmap_file, &width,&height);
+                       load_file_name, &pixmap_file, &pixmap_file2,&width,&height);
 
      if (reti == 0){
        setImageWidth(width);
        setImageHeight(height);
        setValue1((long)pixmap_file);
-       setValue2((long)0);
+       setValue2((long)pixmap_file2);
      }else{
 //WSMFtrace("ERROR. WSDximage::initialize file open error. file=%s\n",load_file_name);
      }
@@ -367,7 +370,16 @@ long WSDximage::createImage(){
   setValue3((long)image);
   return WS_NO_ERR;
 }
-
+XImage* WSDximage::createMaskImage(){
+  Pixmap pix2 = (Pixmap)getValue2();
+  if ((long)pix2 == 0 || (long)pix2 == -1){
+    return NULL;
+  }
+  WSDxappDev* app   = WSGIxwinAppDev();
+  XImage* image = XGetImage(app->display(),pix2,0,0,getImageWidth(),
+                    getImageHeight(),0xffffffff,ZPixmap);
+  return image;
+}
 int WSGFxgetbyte(FILE *fp) {
   int c;
   if ((c = fgetc(fp)) == EOF){
@@ -411,7 +423,7 @@ int WSGFxreadLittleLong(FILE *fp, long *d) {
   return 0;
 }
 
-long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pixmap* pixmap,long* w,long* h){
+long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pixmap* pixmap,Pixmap* pixmap2,long* w,long* h){
 
   // bmp (Windows 3.x) header
   //       implemented
@@ -421,6 +433,7 @@ long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pix
   //            4. uncompressed 24bit true color
   //            5. RLE 4bit  16 color
   //            6. RLE 8bit 256 color
+  *pixmap2 = (Pixmap)0;
   unsigned char red[256], green[256], blue[256];
   if ((WSGFxgetbyte(ifile) != 'B') || (WSGFxgetbyte(ifile) != 'M')){  //  0
     // not a .bmp file
@@ -442,7 +455,9 @@ long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pix
   }
   if (long_tmp != 40){
     // not a Windows 3.x bmp file
-    return -1;
+    if (long_tmp != 0x6c){
+      return -1;
+    }
   }
   if (WSGFxreadLittleLong(ifile, &width) == -1){                 // 18
     return -1;
@@ -460,7 +475,8 @@ long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pix
   if (WSGFxreadLittleShort(ifile, &bit_cnt) == -1){              // 28
     return -1;
   }
-  if ((bit_cnt != 1) && (bit_cnt != 4) && (bit_cnt != 8) && (bit_cnt != 24)){
+  if ((bit_cnt != 1) && (bit_cnt != 4) && (bit_cnt != 8) &&
+      (bit_cnt != 24) && (bit_cnt != 32)){
     // bit_cnt=16 is not supported
     return -1;
   }
@@ -468,8 +484,12 @@ long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pix
     return -1;
   }
   if (cmptype > 2){
-    // compressed file is not supported
-    return -1;
+    if (cmptype == 3 && bit_cnt == 32){
+      // 24bit + mask.
+    }else{
+      // compressed file is not supported
+      return -1;
+    }
   }
   if (WSGFxreadLittleLong(ifile, &long_tmp) == -1){              // 34
     return -1;
@@ -486,6 +506,9 @@ long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pix
   if (WSGFxreadLittleLong(ifile, &long_tmp) == -1){              // 50
     return -1;
   }
+  if ((cmapsize == 0) && (bit_cnt <=8)){
+    cmapsize = 1 << bit_cnt;
+  }
   int n, c;
   for (n = 0; n < cmapsize; n++) {
     if ((c = WSGFxgetbyte(ifile)) == -1){
@@ -513,10 +536,15 @@ long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pix
     return -1;
   }
   unsigned char* buf = new unsigned char[width * height * 3];
+  unsigned char* buf_mask = NULL;
+  if (cmptype == 3){
+    buf_mask = new unsigned char[width * height];
+  }
   unsigned char *tmp, *ftmp;
+  unsigned char *tmp_mask;
 
   int line, dat, x, y;
-
+//printf("cmptype=%d w,h=%d,%d bit=%d\n",cmptype,width,height,bit_cnt);
   if (cmptype) {
     for (y = 0; y < height; y++) {
       tmp = buf + (height - 1 - y) * width * 3;
@@ -537,9 +565,11 @@ long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pix
         // copy N times
         tmp = buf + (((height - 1 - y) * width) + x) * 3;
         for (n = 0; n < *ftmp; n++, x++) {
-          *(tmp++) = red[*(ftmp + 1)];        // red
-          *(tmp++) = green[*(ftmp + 1)];      // green
-          *(tmp++) = blue[*(ftmp + 1)];       // blue
+          if (x<width){
+            *(tmp++) = red[*(ftmp + 1)];        // red
+            *(tmp++) = green[*(ftmp + 1)];      // green
+            *(tmp++) = blue[*(ftmp + 1)];       // blue
+          }
         }
         ftmp += 2;
       } else {
@@ -560,9 +590,11 @@ long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pix
           // copy
           tmp = buf + (((height - 1 - y) * width) + x) * 3;
           for (n = 0; n < *(ftmp + 1); n++, x++) {
-            *(tmp++) = red[*(ftmp + n + 2)];        // red
-            *(tmp++) = green[*(ftmp + n + 2)];      // green
-            *(tmp++) = blue[*(ftmp + n + 2)];       // blue
+            if (x<width){
+              *(tmp++) = red[*(ftmp + n + 2)];        // red
+              *(tmp++) = green[*(ftmp + n + 2)];      // green
+              *(tmp++) = blue[*(ftmp + n + 2)];       // blue
+            }
           }
           ftmp += (*(ftmp + 1) + 2 + (*(ftmp + 1) % 2)?1:0);
         }
@@ -673,28 +705,54 @@ long WSGFxBmpReadFpToPixmap(Display* display,Window window,GC gc,FILE* ifile,Pix
         break;
       case 24:
         tmp = buf;
+        tmp_mask = buf_mask;
         for (y = 0; y < height; y++){
           ftmp = fbuf + ((height - 1 - y) * width * 3);
           for (x = 0; x < width; x++){
             *(tmp++) = *(ftmp + 2);       // red
             *(tmp++) = *(ftmp + 1);       // green
             *(tmp++) = *(ftmp + 0);       // blue
-            ftmp += 3;
+            if (cmptype != 3){
+              ftmp += 3;
+            }else{
+              ftmp += 4;
+            }
           }
         }
         break;
-    }
+      case 32:
+        tmp = buf;
+        tmp_mask = buf_mask;
+        for (y = 0; y < height; y++){
+          ftmp = fbuf + ((height - 1 - y) * width * 4);
+          for (x = 0; x < width; x++){
+            *(tmp++) = *(ftmp + 2);       // red
+            *(tmp++) = *(ftmp + 1);       // green
+            *(tmp++) = *(ftmp + 0);       // blue
+           
+            if (cmptype == 3){
+              *(tmp_mask++) = *(ftmp + 3);       // blue
+//printf("i=%d j=%d pt=%d mask=0x%x\n",y,x,tmp_mask-1 - buf_mask,*(tmp_mask -1));
+            }
+            ftmp += 4;
+          }
+        }
+        break;
+     }
   }
   delete fbuf;
   long reti = WSGFxBufToPixmap(display, window, gc, buf, pixmap, width, height,w,h);
-
   delete buf;
+  if (cmptype == 3){
+    WSGFxBufToBitmap(display, window, gc, buf_mask, pixmap2, width, height,w,h);
+    delete buf_mask;
+  }
+
 //  *w = width;
 //  *h = height;
   return reti;
 }
 
-
 long WSGFxBufToPixmap(Display* display,Window window,GC gc,unsigned char *buf,Pixmap* pixmap,long rwidth,long rheight,long* w,long* h){
 
   int red_mask, green_mask, blue_mask;
@@ -1009,14 +1067,86 @@ long WSGFxBufToPixmap(Display* display,Window window,GC gc,unsigned char *buf,Pi
   return 0;
 }
 
-long WSGFxBmpReadFileToPixmap(Display* display,Window window,GC gc,char* filename,Pixmap* pixmap,long* w,long* h){
+long WSGFxBufToBitmap(Display* display,Window window,GC gc,unsigned char *buf,Pixmap* pixmap,long rwidth,long rheight,long* w,long* h){
+  long stretched = 0;
+  long vwidth = *w;
+  long vheight = *h;
+  if (vwidth == 0 || vheight == 0){
+    vwidth = rwidth;
+    vheight = rheight;
+  }else{
+    if ((long)((double)rwidth * vheight/vwidth) < rheight){
+      vwidth = (long)((double)vheight * rwidth/rheight);
+    }else{
+      vheight = (long)((double)vwidth * rheight/rwidth);
+    }
+    stretched = 1;
+  }
+  *w = vwidth;
+  *h = vheight;
+
+  Visual* visual = XDefaultVisual(display,XDefaultScreen(display));
+  XImage* image = XCreateImage(display,visual, 1,
+                         ZPixmap,0,0,vwidth,vheight,8,0);
+
+//printf("here1 image=0x%x bytes_per_line=%d w.h\n",image,image->bytes_per_line,vwidth,vheight);
+  image->data = new char[image->bytes_per_line * vheight];
+
+  unsigned char v;
+  long ptr = 0;
+  long ptr2 = 0;
+  long i, j;
+
+  for(i=0; i<vheight; i++){
+    for(j=0; j<vwidth; j++){
+      if (stretched != 0){
+        ptr = ((long)((double)i*rheight/vheight)*rwidth
+             + (long)((double)j*rwidth/vwidth));
+      }
+      if ( (j%8) == 0){
+        v = 0;
+      }
+      if (buf[ptr++] == 0){
+        v |= (1<<(j%8));
+      }
+//printf("i=%d j=%d pt=%d pt2=%d bit=%d val=0x%x v=0x%x\n",i,j,ptr,ptr2,j%8,buf[ptr-1],v);
+      if ( (j%8) == 7){
+        ((unsigned char*)image->data)[ptr2] = v;
+        ptr2++;
+      }else
+      if (j == vwidth-1){
+        ((unsigned char*)image->data)[ptr2] = v;
+        ptr2++;
+      }
+    }
+  }
+  GC gc2;
+  XGCValues values;
+
+  values.foreground = 1;
+  values.background = 0;
+  Pixmap pix = XCreatePixmap(display,window, vwidth,vheight,1);
+  gc2 = XCreateGC(display, pix, GCForeground | GCBackground, &values);
+
+  *pixmap = pix;
+  XPutImage(display,pix,gc2,image,0,0,0,0,vwidth,vheight);
+  if (image->data != NULL){
+    delete image->data;
+    image->data = NULL;
+  }
+  XFreeGC(display,gc2);
+  XDestroyImage(image);
+  return 0;
+}
+
+long WSGFxBmpReadFileToPixmap(Display* display,Window window,GC gc,char* filename,Pixmap* pixmap,Pixmap* pixmap2,long* w,long* h){
 
   FILE* ifile = fopen(filename,"r");
   if (ifile == NULL){
     return -1;
   }
 
-  long reti = WSGFxBmpReadFpToPixmap(display, window, gc, ifile, pixmap, w, h);
+  long reti = WSGFxBmpReadFpToPixmap(display, window, gc, ifile, pixmap,pixmap2, w, h);
   fclose(ifile);
   return reti;
 }
